@@ -1,12 +1,13 @@
 import math
 import json
 import logging
+from pydantic import BaseModel
 
 
-class LatLng:
-    def __init__(self, lat, lng):
-        self.lat = lat
-        self.lng = lng
+class LatLng(BaseModel):
+    lat: float
+    lng: float
+
 
 def distance(loc1: LatLng, loc2: LatLng):
     # approximate radius of earth in meter
@@ -25,7 +26,8 @@ def distance(loc1: LatLng, loc2: LatLng):
     c = 2 * math.atan2(math.sqrt(a), math.sqrt(1 - a))
     return R * c
 
-def geojson_to_poly(gjson: str, name:str=None):
+
+def geojson_to_poly(gjson: str, name: str = None):
     loaded = json.loads(gjson)
     if name == None:
         if'name' in loaded:
@@ -39,13 +41,14 @@ def geojson_to_poly(gjson: str, name:str=None):
         raise ValueError('only converting from geojson polygon is supported')
     if len(geometry['coordinates']) > 1:
         logging.warn('multiple coordinates of polygon detected, only using first one as exterior definition')
-    output = [name,'area1']
+    output = [name, 'area1']
     for coord in geometry['coordinates'][0]:
         output.append(f'\t{coord[0]}\t{coord[1]}')
     output.append('END')
     output.append('END')
     return '\n'.join(output)
 
+
 def poly_to_geojson(poly: str):
     gjson = {
         'type': 'FeatureCollection',
@@ -54,7 +57,7 @@ def poly_to_geojson(poly: str):
             {
                 'type': 'Feature',
                 'properties': {},
-                'geometry':{
+                'geometry': {
                     'type': 'Polygon',
                     'coordinates': [
                         []
@@ -63,34 +66,35 @@ def poly_to_geojson(poly: str):
             }
         ]
     }
-    poly = poly.replace('\t',' ')
+    poly = poly.replace('\t', ' ')
     lines = poly.split('\n')
     gjson['name'] = lines[0].strip()
     for line in lines[2:]:
         if line.strip() == 'END':
             break
         coords = [x for x in line.strip().split(' ') if len(x) > 0]
-        gjson['features'][0]['geometry']['coordinates'][0].append([float(coords[0]),float(coords[1])])
+        gjson['features'][0]['geometry']['coordinates'][0].append([float(coords[0]), float(coords[1])])
     return gjson
 
-def parse_poly(pstr:str):
+
+def parse_poly(pstr: str):
     result = []
     lines = pstr.split('\n')
     mode = 0
     coords = []
     for line in lines:
         line = line.rstrip()
-        line = line.replace('\t',' ')
+        line = line.replace('\t', ' ')
         swt = line.startswith(' ')
         if mode == 0 and swt:
-            mode = 1 #begin area
+            mode = 1  # begin area
         if mode == 1 and swt:
-            items = [float(x) for x in line.split(' ') if len(x)>0]
+            items = [float(x) for x in line.split(' ') if len(x) > 0]
             if len(items) == 2:
-                coords.append([items[0],items[1]])
+                coords.append([items[0], items[1]])
             else:
                 raise ValueError(f'invalid line: {line}')
-        if mode==1 and line=='END':
+        if mode == 1 and line == 'END':
             mode = 0
             result.append(coords)
             coords = []
