@@ -11,3 +11,9 @@ END """
     print(f'r is {r}')
     assert len(r) == 1
     assert r[0][0] == [1.2,3.4]
+
+
+def test_parse_poly_file():
+    with open('bangalore.poly') as f:
+        p = geo.parse_poly(f.read())
+        assert len(p) > 0
